import React from 'react'
import { VelocityComponent } from 'velocity-react'
import Subsection from './nav-panel-bottom-subsection'

const animation = {
  active: { opacity: 1 },
  inactive: { opacity: 0 }
}

const NavPanelBottom = ({ isMobile, isOpen, activeSection, sections, midSections }) => (
  <div className='nav-panel-bottom'>
    { sections.map((section, i) =>
      <div
        key={ i }
        style={{ width: 'inherit' }}
        className={ !(isMobile && isOpen) && activeSection !== i
          ? 'nav-panel-bottom__section--inactive'
          : '' }>
        <VelocityComponent
          animation={ (isMobile && isOpen) || activeSection === i
            ? animation.active
            : animation.inactive
          }
          duration='300'
          delay={ activeSection !== i ? 100 : 0 }>
          <Subsection
            count={ i }
            midSection={ midSections[i] }
            { ...section } />
        </VelocityComponent>
      </div>
    ) }
  </div>
)

const { number, bool, string, array } = React.PropTypes

NavPanelBottom.propTypes = {
  activeSection: number,
  isOpen: bool.isRequired,
  isMobile: bool.isRequired,
  environment: string,
  sections: array,
  midSections: array
}

NavPanelBottom.defaultProps = {
  environment: 'com'
}

export default NavPanelBottom
